==> vue-loading-status-2.0.0.tgz: package/README.md <==
# vue-loading-status

This is a vue loading

![loading icon](https://raw.githubusercontent.com/lijianhuiGit/vue-loading-status/master/src/icon/demo.png)

## Usage
```javascript

npm install vue-loading-status --save

import loadingStatus from 'vue-loading-status'

loadingStatus.config.loadingText = 'loading'
loadingStatus.config.successText = 'success'
loadingStatus.config.emptyText = 'empty'
loadingStatus.config.errorText = 'error'

Vue.use(loadingStatus)

```

```html
<template>
    <ul v-if="productList.length">
        <li v-for="item in productList">item product</li>
    </ul>
    <loading-status v-else :status="productListStatus"></loading-status>

    <!-- other option
    <loading-status 
        :status="productListStatus"
        :height="200"
        :global="[true / false]"
    >
    </loading-status>
    -->

</template>
```
```javascript
<script>
export default {
    data () {
        return {
            productList: [],
            productListStatus: null
        }
    },
    created () {
        this.productListStatus = [true, 'loading...']
        axios.get('/get-product-list')
            .then(res => {
                if (res.data) {
                    this.productList = res.data
                    this.productListStatus = [1, 'success']
                }
                else {
                    this.productListStatus = [0, 'empty']
                }
            })
            .catch(err => {
                this.productListStatus = [-1, 'error']
            })
    }
}
</script>
```

==> vue-loading-status-2.0.2.tgz: package/README.md <==
# vue-loading-status

This is a vue loading

![loading icon](https://raw.githubusercontent.com/lijianhuiGit/vue-loading-status/master/src/icon/demo.png)

## Usage
```javascript

npm install vue-loading-status --save

import loadingStatus from 'vue-loading-status'

loadingStatus.config.loadingMsg = 'loading'
loadingStatus.config.successMsg = 'success'
loadingStatus.config.emptyMsg = 'empty'
loadingStatus.config.errorMsg = 'error'

Vue.use(loadingStatus)

```

```html
<template>
    <ul v-if="productList.length">
        <li v-for="item in productList">item product</li>
    </ul>
    <loading-status v-else :status="productListStatus"></loading-status>

    <!-- other option
    <loading-status 
        :status="productListStatus"
        :height="200"
        :global="[true / false]"
    >
    </loading-status>
    -->

</template>
```
```javascript
<script>
export default {
    data () {
        return {
            productList: [],
            productListStatus: null
        }
    },
    created () {
        this.productListStatus = [true, 'loading...']
        axios.get('/get-product-list')
            .then(res => {
                if (res.data) {
                    this.productList = res.data
                    this.productListStatus = [1, 'success']
                }
                else {
                    this.productListStatus = [0, 'empty']
                }
            })
            .catch(err => {
                this.productListStatus = [-1, 'error']
            })
    }
}
</script>
```
